summaryrefslogtreecommitdiffstats
path: root/chrome/browser/icon_manager_linux.cc
diff options
context:
space:
mode:
authorthestig@chromium.org <thestig@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-11 20:41:21 +0000
committerthestig@chromium.org <thestig@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-11 20:41:21 +0000
commite5285892d1f34618bf65f207c73eaed2e61357f3 (patch)
tree3029892991a00a440f3bfba91ef6c8edfb7ef292 /chrome/browser/icon_manager_linux.cc
parent7e98f94bf8b44c8b16b81a4b12700ed425343f91 (diff)
downloadchromium_src-e5285892d1f34618bf65f207c73eaed2e61357f3.zip
chromium_src-e5285892d1f34618bf65f207c73eaed2e61357f3.tar.gz
chromium_src-e5285892d1f34618bf65f207c73eaed2e61357f3.tar.bz2
Linux: Move base/mime_util* to base/nix. It's not used on any other platform.
BUG=none TEST=none Review URL: http://codereview.chromium.org/8538008 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@109685 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/icon_manager_linux.cc')
-rw-r--r--chrome/browser/icon_manager_linux.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/icon_manager_linux.cc b/chrome/browser/icon_manager_linux.cc
index fc3cfa8..df7c629 100644
--- a/chrome/browser/icon_manager_linux.cc
+++ b/chrome/browser/icon_manager_linux.cc
@@ -4,16 +4,16 @@
#include "chrome/browser/icon_manager.h"
-#include "base/mime_util.h"
+#include "base/nix/mime_util_xdg.h"
#include "base/threading/thread_restrictions.h"
IconGroupID IconManager::GetGroupIDFromFilepath(const FilePath& filepath) {
// It turns out the call to mime_util::GetFileMimeType below does IO, but
// callers of GetGroupIDFromFilepath assume it does not do IO (the Windows
// and Mac implementations do not). We should fix this by either not doing IO
// in this method, or reworking callers to avoid calling it on the UI thread.
// See crbug.com/72740.
base::ThreadRestrictions::ScopedAllowIO allow_io;
- return mime_util::GetFileMimeType(filepath);
+ return base::nix::GetFileMimeType(filepath);
}
@@ -4,16 +4,16 @@
#include "base/threading/thread_restrictions.h"
IconGroupID IconManager::GetGroupIDFromFilepath(const FilePath& filepath) {
- // It turns out the call to mime_util::GetFileMimeType below does IO, but
+ // It turns out the call to base::nix::GetFileMimeType below does IO, but
// callers of GetGroupIDFromFilepath assume it does not do IO (the Windows
// and Mac implementations do not). We should fix this by either not doing IO